<?php

declare(strict_types=1);

namespace Dedi\SyliusBlogPlugin\Factory;

use Dedi\SyliusBlogPlugin\Domain\Blog\Adapter\ArticleRepositoryInterface;
use Dedi\SyliusBlogPlugin\Entity\Comment;
use Dedi\SyliusBlogPlugin\Entity\CommentInterface;
use Sylius\Component\Core\Model\ChannelInterface;
use Sylius\Component\Resource\Factory\FactoryInterface;
use Symfony\Component\Security\Core\Authentication\Token\Storage\TokenStorageInterface;

final class CommentFactory implements CommentFactoryInterface
{
    private FactoryInterface $factory;

    private ArticleRepositoryInterface $articleRepository;

    private TokenStorageInterface $tokenStorage;

    /**
     * @param FactoryInterface $factory
     */
    public function __construct(FactoryInterface $factory, ArticleRepositoryInterface $articleRepository, TokenStorageInterface $tokenStorage)
    {
        $this->factory = $factory;
        $this->articleRepository = $articleRepository;
        $this->tokenStorage = $tokenStorage;
    }

    /**
     * {@inheritDoc}
     */
    public function createNew()
    {
        return $this->factory->createNew();
    }


    public function createNewWithArticle(ChannelInterface $channel, $articleSlug, $locale): CommentInterface
    {
        /** @var Comment $comment */
        $comment = $this->createNew();
        $comment->setArticle($this->articleRepository->findOneByChannelAndSlug($channel, $articleSlug, $locale));
        $comment->setCustomer($this->tokenStorage->getToken()->getUser()->getCustomer());

        return $comment;
    }

    public function setArticleRepository(ArticleRepositoryInterface $articleRepository)
    {
        $this->articleRepository = $articleRepository;
    }
}
