<?php

declare(strict_types=1);

namespace Dedi\SyliusBlogPlugin\Form;

use Dedi\SyliusBlogPlugin\Entity\BlogConfiguration;
use Sylius\Bundle\ChannelBundle\Form\Type\ChannelChoiceType;
use Sylius\Bundle\ResourceBundle\Form\Type\ResourceTranslationsType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Validator\Constraints\Valid;

class BlogConfigurationType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('channel', ChannelChoiceType::class, [
                'multiple' => false,
                'expanded' => true,
                'label' => 'dedi_blog.form.channel',
            ])
            ->add('headerDisplayable', CheckboxType::class, [
                'label' => 'dedi_blog.form.configuration.header_displayable'
            ])
            ->add('banner', BlogConfigurationBannerType::class, [
                'required' => false,
                'label' => 'dedi_blog.form.article.banner',
            ])
            ->add('translations', ResourceTranslationsType::class, [
                'entry_type' => BlogConfigurationTranslationType::class,
                'constraints' => [new Valid()]
            ])
        ;
    }

    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults([
            'data_class' => BlogConfiguration::class,
            'validation_groups' => ['default', 'sylius'],
        ]);
    }
}
