<?php

declare(strict_types=1);

namespace Dedi\SyliusBlogPlugin\Repository;

use Dedi\SyliusBlogPlugin\Domain\Blog\Adapter\ArticleRepositoryInterface;
use Dedi\SyliusBlogPlugin\Entity\Category;
use Pagerfanta\Pagerfanta;
use Sylius\Bundle\ResourceBundle\Doctrine\ORM\EntityRepository;
use Sylius\Component\Core\Model\ChannelInterface;

class ArticleRepository extends AbstractRepository implements ArticleRepositoryInterface
{
    public function findByCategoryAndChannel(Category $category, ChannelInterface $channel, ?string $locale = null): Pagerfanta
    {
        $builder = $this->createBaseQueryBuilder($channel, $locale)
            ->andWhere(':category MEMBER OF o.categories')
            ->setParameter('category', $category)
        ;

        return $this->getPaginator($builder);
    }

    public function findByChannel(ChannelInterface $channel, ?string $locale = null): Pagerfanta
    {
        $builder = $this->createBaseQueryBuilder($channel, $locale)
            ->addOrderBy('o.createdAt', 'DESC')
        ;

        return $this->getPaginator($builder);
    }
}
